@@ -17,10 +17,10 @@ Plugin_Tag_Table = Table(
 
 
 class PluginCreate(BaseModel):
-  name: str
+  urn: str
   description: str
   author: str
-  version: str
+  path: str
 
 
 class Plugin(PluginCreate):
@@ -33,8 +33,8 @@ class Plugin(PluginCreate):
 class PluginModel(Base):
   __tablename__ = 'plugins'
   id = Column(Integer, primary_key=True, index=True)
-  name = Column(String)
+  urn = Column(String)
   description = Column(String)
   author = Column(String)
-  version = Column(String)
+  path = Column(String)
   tags = relationship("TagModel", secondary=Plugin_Tag_Table)
