@@ -1,5 +1,5 @@
 from pydantic import BaseModel 
-from sqlalchemy import Column, String, Integer
+from sqlalchemy import Column, String, Integer, ForeignKey
 
 from poindexter.models import Base
 
